@@ -53,18 +53,18 @@ let build_rule () =
   in
   rule "BUILD" ~deps ~prod builder
 
+let read_build () =
+  let ic = open_in "BUILD" in
+  let version = input_line ic in
+  let build = input_line ic in
+  close_in ic;
+  version, build
+
 let version_rules kind =
-  let file = "BUILD" in
-  let deps = [file; "src/platform/" ^ kind ^ "/belenios_version.mli"] in
+  let deps = ["BUILD"; "src/platform/" ^ kind ^ "/belenios_version.mli"] in
   let prod = "src/platform/" ^ kind ^ "/belenios_version.ml" in
   let builder _ _ =
-    let version, build =
-      let ic = open_in file in
-      let version = input_line ic in
-      let build = input_line ic in
-      close_in ic;
-      version, build
-    in
+    let version, build = read_build () in
     let lines = Printf.([
       sprintf "let version = \"%s\"" version;
       sprintf "let build = \"%s\"" build;
@@ -78,6 +78,16 @@ let version_rules kind =
     ("src/platform/" ^ kind ^ "/belenios_version.mli");
   rule ("BUILD -> " ^ kind ^ "/belenios_version.ml") ~deps ~prod builder
 
+let meta_rule () =
+  let meta_in = "META.in" in
+  let deps = [meta_in; "BUILD"] in
+  let prod = "lib/belenios/META" in
+  let builder _ _ =
+    let version, _ = read_build () in
+    Cmd (S [A "sed"; A (Printf.sprintf "s/@VERSION@/%s/" version); P meta_in; Sh ">"; P prod])
+  in
+  rule "META" ~deps ~prod builder
+
 let copy_static f =
   let base = Filename.basename f in
   copy_rule base f ("src/static" / base)
@@ -101,6 +111,9 @@ let () = dispatch & function
     (* the following avoids an ocamlfind warning, it should be built-in *)
     flag ["doc"; "thread"] (A"-thread");
 
+    (* there seems to be no built-in tag for this... *)
+    flag ["compile"; "interf"] (A"-no-keep-locs");
+
     rule "%.atd -> %_t.ml & %_t.mli" ~deps:["%.atd"] ~prods:["%_t.ml"; "%_t.mli"]
       (atdgen_action [A"-t"]);
     rule "%.atd -> %_j.ml & %_j.mli" ~deps:["%.atd"] ~prods:["%_j.ml"; "%_j.mli"]
@@ -114,28 +127,32 @@ let () = dispatch & function
       );
 
     build_rule ();
+    meta_rule ();
     version_rules "native";
     version_rules "js";
     platform_rules "native";
     platform_rules "js";
 
-    copy_rule "jsbn.js" "ext/booth/js/jsbn/jsbn.js" "src/static/jsbn.js";
-    copy_rule "jsbn2.js" "ext/booth/js/jsbn/jsbn2.js" "src/static/jsbn2.js";
-    copy_rule "sjcl.js" "ext/booth/js/sjcl/sjcl.js" "src/static/sjcl.js";
+    copy_rule "BigIntCompat.js" "ext/jsbn/BigIntCompat.js" "src/static/BigIntCompat.js";
+    copy_rule "sjcl.js" "ext/sjcl/sjcl.js" "src/static/sjcl.js";
     copy_rule "random.js" "src/platform/js/random.js" "src/static/random.js";
 
     copy_rule "belenios-tool" ("src/tool/tool_cmdline" ^ exe_suffix) "belenios-tool";
     copy_rule "belenios-tool.js" "src/tool/tool_js.js" "src/static/tool_js.js";
     copy_rule "belenios-tool.html" "src/tool/belenios-tool.html" "src/static/belenios-tool.html";
 
-    copy_rule "encrypting.gif" "ext/booth/encrypting.gif" "src/static/encrypting.gif";
-    copy_rule "booth.js" "src/booth/booth.js" "src/static/booth.js";
+    copy_rule "encrypting.gif" "ext/images/encrypting.gif" "src/static/encrypting.gif";
 
+    copy_rule "tool_js_booth.js" "src/tool/tool_js_booth.js" "src/static/tool_js_booth.js";
     copy_rule "tool_js_tkeygen.js" "src/tool/tool_js_tkeygen.js" "src/static/tool_js_tkeygen.js";
     copy_rule "tool_js_ttkeygen.js" "src/tool/tool_js_ttkeygen.js" "src/static/tool_js_ttkeygen.js";
     copy_rule "tool_js_credgen.js" "src/tool/tool_js_credgen.js" "src/static/tool_js_credgen.js";
     copy_rule "tool_js_questions.js" "src/tool/tool_js_questions.js" "src/static/tool_js_questions.js";
     copy_rule "tool_js_pd.js" "src/tool/tool_js_pd.js" "src/static/tool_js_pd.js";
+    copy_rule "tool_js_shuffle.js" "src/tool/tool_js_shuffle.js" "src/static/tool_js_shuffle.js";
+
+    copy_rule "server.cma" "src/web/server.cma" "lib/belenios/server.cma";
+    copy_rule "server.cmxs" "src/web/server.cmxs" "lib/belenios/server.cmxs";
 
     List.iter
       copy_static
