@@ -4,9 +4,10 @@ set -e
 
 BELENIOS_SRC="${BELENIOS_SRC:-$PWD}"
 
-# Check that OCamlDuce is not installed
-if which ocamlduce >/dev/null; then
-    echo "Please uninstall OCamlDuce first, or remove it from your PATH."
+# Check that Dune is not installed
+# cf. https://github.com/ocaml/opam/issues/3987
+if command -v dune >/dev/null; then
+    echo "Please uninstall Dune first, or remove it from your PATH."
     exit 1
 fi
 
@@ -34,43 +35,26 @@ fi
 mkdir -p "$BELENIOS_SYSROOT/bootstrap/src"
 
 cd "$BELENIOS_SYSROOT/bootstrap/src"
-wget http://caml.inria.fr/pub/distrib/ocaml-4.02/ocaml-4.02.3.tar.gz
-wget https://github.com/ocaml/opam/releases/download/1.2.2/opam-full-1.2.2.tar.gz
+wget https://github.com/ocaml/opam/releases/download/2.0.5/opam-full-2.0.5.tar.gz
 
 if which sha256sum >/dev/null; then
 sha256sum --check <<EOF
-928fb5f64f4e141980ba567ff57b62d8dc7b951b58be9590ffb1be2172887a72  ocaml-4.02.3.tar.gz
-15e617179251041f4bf3910257bbb8398db987d863dd3cfc288bdd958de58f00  opam-full-1.2.2.tar.gz
+776c7e64d6e24c2ef1efd1e6a71d36e007645efae94eaf860c05c1929effc76f  opam-full-2.0.5.tar.gz
 EOF
 else
     echo "WARNING: sha256sum was not found, checking tarballs is impossible!"
 fi
 
-echo
-echo "=-=-= Compilation and installation of OCaml =-=-="
-echo
-cd "$BELENIOS_SYSROOT/bootstrap/src"
-tar -xzf ocaml-4.02.3.tar.gz
-cd ocaml-4.02.3
-./configure -prefix "$BELENIOS_SYSROOT/bootstrap"
-make world
-if ! grep -q ARCH=none config/Makefile; then
-  make opt
-  make opt.opt
-fi
-make install
 export PATH="$BELENIOS_SYSROOT/bootstrap/bin:$PATH"
 
 echo
 echo "=-=-= Compilation and installation of OPAM =-=-="
 echo
 cd "$BELENIOS_SYSROOT/bootstrap/src"
-tar -xzf opam-full-1.2.2.tar.gz
-cd opam-full-1.2.2
-./configure -prefix "$BELENIOS_SYSROOT/bootstrap"
-make lib-ext
-make
-make install
+tar -xzf opam-full-2.0.5.tar.gz
+cd opam-full-2.0.5
+make cold CONFIGURE_ARGS="--prefix $BELENIOS_SYSROOT/bootstrap"
+make cold-install LIBINSTALL_DIR="$BELENIOS_SYSROOT/bootstrap/lib/ocaml"
 
 echo
 echo "=-=-= Generation of env.sh =-=-="
@@ -78,21 +62,24 @@ echo
 cat > $BELENIOS_SRC/env.sh <<EOF
 PATH="$BELENIOS_SYSROOT/bootstrap/bin:\$PATH"; export PATH;
 OPAMROOT=$OPAMROOT; export OPAMROOT;
-eval \`opam config env\`
+eval \$(opam env)
 EOF
 
 echo
 echo "=-=-= Initialization of OPAM root =-=-="
 echo
-opam init --no-setup
-eval `opam config env`
-opam switch 4.02.3
-eval `opam config env`
+cd "$BELENIOS_SYSROOT"
+git clone https://github.com/ocaml/opam-repository.git
+cd opam-repository
+git reset --hard b05d48934714c55dcc3c11ea41dc9f53ca80bb76
+opam init --bare --no-setup -k git "$BELENIOS_SYSROOT/opam-repository"
+opam switch create 4.08.1 ocaml-base-compiler.4.08.1
+eval $(opam env)
 
 echo
 echo "=-=-= Installation of Belenios build-dependencies =-=-="
 echo
-opam install --yes atdgen=1.12.0 zarith cryptokit uuidm calendar cmdliner sqlite3 eliom=4.2.0 csv
+opam install --yes atdgen zarith cryptokit uuidm calendar cmdliner sqlite3 csv eliom
 
 echo
 echo "=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-="
