@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -19,28 +19,19 @@
 (*  <http://www.gnu.org/licenses/>.                                       *)
 (**************************************************************************)
 
-open Signatures
+open Signatures_core
 
 module Array : sig
   include module type of Array
   val exists : ('a -> bool) -> 'a array -> bool
   val forall : ('a -> bool) -> 'a array -> bool
   val forall2 : ('a -> 'b -> bool) -> 'a array -> 'b array -> bool
-  val fforall : ('a -> bool) -> 'a array array -> bool
-  val fforall2 : ('a -> 'b -> bool) ->
-    'a array array -> 'b array array -> bool
-  val fforall3 : ('a -> 'b -> 'c -> bool) ->
-    'a array array -> 'b array array -> 'c array array -> bool
+  val forall3 : ('a -> 'b -> 'c -> bool) -> 'a array -> 'b array -> 'c array -> bool
   val map2 : ('a -> 'b -> 'c) -> 'a array -> 'b array -> 'c array
   val map3 : ('a -> 'b -> 'c -> 'd) ->
     'a array -> 'b array -> 'c array -> 'd array
-  val mmap : ('a -> 'b) -> 'a array array -> 'b array array
-  val mmap2 : ('a -> 'b -> 'c) ->
-    'a array array -> 'b array array -> 'c array array
-  val mmap3 : ('a -> 'b -> 'c -> 'd) ->
-    'a array array -> 'b array array -> 'c array array -> 'd array array
-  val ssplit : ('a * 'b) array array -> 'a array array * 'b array array
   val findi : (int -> 'a -> 'b option) -> 'a array -> 'b option
+  val split : ('a * 'b) array -> 'a array * 'b array
 end
 
 module String : sig
@@ -48,16 +39,42 @@ module String : sig
   val startswith : string -> string -> bool
 end
 
-val list_join : 'a -> 'a list -> 'a list
+module List : sig
+  include module type of List
+  val join : 'a -> 'a list -> 'a list
+  val filter_map : ('a -> 'b option) -> 'a list -> 'b list
+end
 
-val option_map : ('a -> 'b) -> 'a option -> 'b option
+module Option : sig
+  val iter : ('a -> unit) -> 'a option -> unit
+  val get : 'a option -> 'a -> 'a
+  val map : ('a -> 'b) -> 'a option -> 'b option
+end
+
+module Shape : sig
+  type 'a t =
+    | SAtomic of 'a
+    | SArray of 'a t array
+  val of_array : 'a array -> 'a t
+  val to_array : 'a t -> 'a array
+  val to_shape_array : 'a t -> 'a t array
+  val map : ('a -> 'b) -> 'a t -> 'b t
+  val map2 : ('a -> 'b -> 'c) -> 'a t -> 'b t -> 'c t
+  val flatten : 'a t -> 'a list
+  val split : ('a * 'b) t -> 'a t * 'b t
+  val forall : ('a -> bool) -> 'a t -> bool
+  val forall2 : ('a -> 'b -> bool) -> 'a t -> 'b t -> bool
+  val forall3 : ('a -> 'b -> 'c -> bool) -> 'a t -> 'b t -> 'c t -> bool
+end
 
 val save_to : string -> (Bi_outbuf.t -> 'a -> unit) -> 'a -> unit
 
 val compare_b64 : string -> string -> int
 
+module SSet : Set.S with type elt = string
 module SMap : Map.S with type key = string
 
 val bytes_to_sample : Platform.Z.t -> int
+val check_modulo : Platform.Z.t -> Platform.Z.t -> bool
 
 module DirectRandom : RANDOM with type 'a t = 'a
