@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -56,16 +56,15 @@ end
 let check x =
   String.length x = token_length + 1 &&
   let rec loop i accu =
-    if i < token_length then (
-      let digit = String.index digits x.[i] in
-      loop (i+1) Z.(n58 * accu + of_int digit)
-    ) else accu
+    if i < token_length then
+      match String.index_opt digits x.[i] with
+      | Some digit -> loop (i+1) Z.(n58 * accu + of_int digit)
+      | None -> None
+    else Some accu
   in
-  try
-    let n = loop 0 Z.zero in
-    let checksum = String.index digits x.[token_length] in
-    Z.((n + of_int checksum) mod n53 =% zero)
-  with Not_found -> false
+  match loop 0 Z.zero, String.index_opt digits x.[token_length] with
+  | Some n, Some checksum -> Z.((n + of_int checksum) mod n53 =% zero)
+  | _, _ -> false
 
 let remove_dashes x =
   let n = String.length x in
@@ -88,6 +87,6 @@ module MakeDerive (G : GROUP) = struct
       | None ->
          pbkdf2_utf8 ~iterations:1000 ~salt:uuid x
     in
-    Z.(of_string_base 16 derived mod G.q)
+    Z.(of_hex derived mod G.q)
 
 end
