@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -19,6 +19,8 @@
 (*  <http://www.gnu.org/licenses/>.                                       *)
 (**************************************************************************)
 
+val debug : string -> unit
+
 val sha256_hex : string -> string
 val sha256_b64 : string -> string
 val pbkdf2_hex : iterations:int -> salt:string -> string -> string
@@ -41,21 +43,23 @@ module Z : sig
   val one : t
   val of_int : int -> t
   val of_string : string -> t
-  val of_string_base : int -> string -> t
+  val of_hex : string -> t
   val ( + ) : t -> t -> t
   val ( - ) : t -> t -> t
   val ( * ) : t -> t -> t
+  val ( / ) : t -> t -> t
   val ( mod ) : t -> t -> t
   val erem : t -> t -> t
   val to_int : t -> int
   val to_string : t -> string
   val compare : t -> t -> int
   val ( =% ) : t -> t -> bool
-  val geq : t -> t -> bool
-  val lt : t -> t -> bool
   val powm : t -> t -> t -> t
   val invert : t -> t -> t
   val probab_prime : t -> int -> int
   val bit_length : t -> int
   val of_bits : string -> t
+  val shift_left : t -> int -> t
+  val shift_right : t -> int -> t
+  val logand : t -> t -> t
 end
