@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -20,10 +20,10 @@
 (**************************************************************************)
 
 open Platform
+open Common
 
 type number = Z.t
 type uuid = string
-type int_or_null = int option
 
 let digits = "123456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnopqrstuvwxyz"
 let min_uuid_length = 14 (* at least 82 bits of entropy *)
@@ -33,8 +33,9 @@ let check token =
   n >= min_uuid_length &&
     let rec loop i =
       if i >= 0 then
-        let digit = try String.index digits token.[i] with Not_found -> -1 in
-        if digit >= 0 then loop (i-1) else false
+        match String.index_opt digits token.[i] with
+        | Some _ -> loop (i-1)
+        | None -> false
       else true
     in loop (n-1)
 
@@ -47,6 +48,6 @@ let uuid_of_raw_string x =
 
 let raw_string_of_uuid x = x
 
-module SSet = Set.Make(String)
-
-type string_set = SSet.t
+type 'a shape = 'a Shape.t =
+  | SAtomic of 'a
+  | SArray of 'a shape array
