@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -29,65 +29,7 @@ open Serializable_t
 type 'a reader = Yojson.Safe.lexer_state -> Lexing.lexbuf -> 'a
 type 'a writer = Bi_outbuf.t -> 'a -> unit
 
-(** A group suitable for discrete logarithm-based cryptography. *)
-module type GROUP = sig
-  (** The following interface is redundant: it is assumed, but not
-      checked, that usual mathematical relations hold. *)
-
-  type t
-  (** The type of elements. Note that it may be larger than the group
-      itself, hence the [check] function below. *)
-
-  val check : t -> bool
-  (** Check group membership. *)
-
-  val one : t
-  (** The neutral element of the group. *)
-
-  val g : t
-  (** A generator of the group. *)
-
-  val q : Z.t
-  (** The order of [g]. *)
-
-  val ( *~ ) : t -> t -> t
-  (** Multiplication. *)
-
-  val ( **~ ) : t -> Z.t -> t
-  (** Exponentiation. *)
-
-  val ( =~ ) : t -> t -> bool
-  (** Equality test. *)
-
-  val invert : t -> t
-  (** Inversion. *)
-
-  val to_string : t -> string
-  (** Conversion to string. *)
-
-  val of_string : string -> t
-  (** Conversion from string. *)
-
-  val read : t reader
-  (** Reading from a stream. *)
-
-  val write : t writer
-  (** Writing to a stream. *)
-
-  val hash : string -> t array -> Z.t
-  (** Hash an array of elements into an integer mod [q]. The string
-      argument is a string that is prepended before computing the hash. *)
-
-  val compare : t -> t -> int
-  (** A total ordering over the elements of the group. *)
-
-  type group
-  (** Serializable description of the group. *)
-
-  val group : group
-  val write_group : group writer
-
-end
+module type GROUP = Signatures_core.GROUP
 
 (** A public key with its group *)
 module type WRAPPED_PUBKEY = sig
@@ -95,21 +37,8 @@ module type WRAPPED_PUBKEY = sig
   val y : G.t
 end
 
-(** Monad signature. *)
-module type MONAD = sig
-  type 'a t
-  val return : 'a -> 'a t
-  val bind : 'a t -> ('a -> 'b t) -> 'b t
-  val fail : exn -> 'a t
-end
-
-(** Random number generation. *)
-module type RANDOM = sig
-  include MONAD
-
-  val random : Z.t -> Z.t t
-  (** [random q] returns a random number modulo [q]. *)
-end
+module type MONAD = Signatures_core.MONAD
+module type RANDOM = Signatures_core.RANDOM
 
 (** Election data needed for cryptographic operations. *)
 type 'a election = {
@@ -147,18 +76,6 @@ module type ELECTION = sig
   type private_key = Z.t
   type public_key = elt
 
-  (** {2 Ciphertexts} *)
-
-  type ciphertext = elt Serializable_t.ciphertext array array
-  (** A ciphertext that can be homomorphically combined. *)
-
-  val neutral_ciphertext : unit -> ciphertext
-  (** The neutral element for [combine_ciphertext] below. *)
-
-  val combine_ciphertexts : ciphertext -> ciphertext -> ciphertext
-  (** Combine two ciphertexts. The encrypted tally of an election is
-      the combination of all ciphertexts of valid cast ballots. *)
-
   (** {2 Ballots} *)
 
   type plaintext = Serializable_t.plaintext
@@ -171,14 +88,7 @@ module type ELECTION = sig
       answers and cryptographic proofs that they satisfy the election
       constraints. *)
 
-  type randomness
-  (** Randomness needed to create a ballot. *)
-
-  val make_randomness : unit -> randomness m
-  (** Creates randomness for [create_ballot] below. The result can be
-      kept for Benaloh-style auditing. *)
-
-  val create_ballot : ?sk:private_key -> randomness -> plaintext -> ballot m
+  val create_ballot : ?sk:private_key -> plaintext -> ballot m
   (** [create_ballot r answers] creates a ballot, or raises
       [Invalid_argument] if [answers] doesn't satisfy the election
       constraints. The private key, if given, will be used to sign
@@ -188,8 +98,15 @@ module type ELECTION = sig
   (** [check_ballot b] checks all the cryptographic proofs in [b]. All
       ballots produced by [create_ballot] should pass this check. *)
 
-  val extract_ciphertext : ballot -> ciphertext
-  (** Extract the ciphertext from a ballot. *)
+  (** {2 Tally} *)
+
+  val process_ballots : ballot array -> elt encrypted_tally
+
+  val extract_nh_ciphertexts : elt encrypted_tally -> elt nh_ciphertexts
+  val merge_nh_ciphertexts : elt nh_ciphertexts -> elt encrypted_tally -> elt encrypted_tally
+
+  val shuffle_ciphertexts : elt nh_ciphertexts -> elt shuffle m
+  val check_shuffle : elt nh_ciphertexts -> elt shuffle -> bool
 
   (** {2 Partial decryptions} *)
 
@@ -198,29 +115,29 @@ module type ELECTION = sig
       private key share and the encrypted tally, and contains a
       cryptographic proof that he or she didn't cheat. *)
 
-  val compute_factor : ciphertext -> private_key -> factor m
+  val compute_factor : elt Serializable_t.ciphertext shape -> private_key -> factor m
 
-  val check_factor : ciphertext -> public_key -> factor -> bool
+  val check_factor : elt Serializable_t.ciphertext shape -> public_key -> factor -> bool
   (** [check_factor c pk f] checks that [f], supposedly submitted by a
       trustee whose public_key is [pk], is valid with respect to the
       encrypted tally [c]. *)
 
   (** {2 Result} *)
 
-  type result = elt Serializable_t.result
+  type result = elt Serializable_t.election_result
   (** The election result. It contains the needed data to validate the
       result from the encrypted tally. *)
 
-  type combinator = factor list -> elt array array
-
-  val compute_result : int -> ciphertext -> factor list -> combinator -> result
+  val compute_result :
+    ?shuffles:elt shuffle list -> ?shufflers:shuffler list ->
+    int -> elt Serializable_t.ciphertext shape -> factor list -> elt trustees -> result
   (** Combine the encrypted tally and the factors from all trustees to
       produce the election result. The first argument is the number of
       tallied ballots. May raise [Invalid_argument]. *)
 
-  val check_result : combinator -> result -> bool
+  val check_result : elt trustees -> result -> bool
 
-  val extract_tally : result -> plaintext
+  val extract_tally : result -> int shape
   (** Extract the plaintext result of the election. *)
 end
 
@@ -260,10 +177,15 @@ module type PEDERSEN = sig
   val step5 : certs -> string -> vinput -> elt voutput m
   val step5_check : certs -> int -> polynomial array -> elt voutput -> bool
   val step6 : certs -> polynomial array -> elt voutput array -> elt threshold_parameters
+end
 
-  val check : elt threshold_parameters -> bool
-  val combine : elt threshold_parameters -> elt
+module type MIXNET = sig
+  type 'a m
+  type elt
 
-  type checker = elt -> elt partial_decryption -> bool
-  val combine_factors : checker -> elt threshold_parameters -> elt partial_decryption list -> elt array array
+  type 'a proof
+
+  val gen_shuffle : elt -> elt ciphertext array -> (elt ciphertext array * number array * int array) m
+  val gen_shuffle_proof : elt -> elt ciphertext array -> elt ciphertext array -> number array -> int array -> elt proof m
+  val check_shuffle_proof : elt -> elt ciphertext array -> elt ciphertext array -> elt proof -> bool
 end
