@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -33,16 +33,28 @@ let stream_to_list s =
 let lines_of_file fname =
   let ic = open_in fname in
   Stream.from (fun _ ->
-    try Some (input_line ic)
-    with End_of_file -> close_in ic; None
-  )
+      match input_line ic with
+      | line -> Some line
+      | exception End_of_file -> close_in ic; None
+    )
 
 let lines_of_stdin () =
   Stream.from (fun _ ->
-      try Some (input_line stdin)
-      with End_of_file -> None
+      match input_line stdin with
+      | line -> Some line
+      | exception End_of_file -> None
     )
 
+let chars_of_stdin () =
+  let buf = Buffer.create 1024 in
+  let rec loop () =
+    match input_char stdin with
+    | c -> Buffer.add_char buf c; loop ()
+    | exception End_of_file -> ()
+  in
+  loop ();
+  Buffer.contents buf
+
 let string_of_file f =
   lines_of_file f |> stream_to_list |> String.concat "\n"
 
@@ -86,17 +98,37 @@ let get_mandatory_opt name = function
   | None -> failcmd "%s is mandatory" name
 
 let wrap_main f =
-  try
-    let () = f () in `Ok ()
-  with
-  | Cmdline_error e -> `Error (true, e)
-  | Failure e -> `Error (false, e)
-  | e -> `Error (false, Printexc.to_string e)
+  match f () with
+  | () -> `Ok ()
+  | exception Cmdline_error e -> `Error (true, e)
+  | exception Failure e -> `Error (false, e)
+  | exception e -> `Error (false, Printexc.to_string e)
 
 module type CMDLINER_MODULE = sig
   val cmds : (unit Cmdliner.Term.t * Cmdliner.Term.info) list
 end
 
+module Shasum : CMDLINER_MODULE = struct
+
+  let main () =
+    wrap_main (fun () -> chars_of_stdin () |> sha256_b64 |> print_endline)
+
+  let sha256_b64_cmd =
+    let doc = "compute SHA256 of standard input and encode it in Base64Compact" in
+    let man = [
+        `S "DESCRIPTION";
+        `P "This command compute the SHA256 of standard input and encode it in Base64Compact. This computation is frequent when auditing an election. This single shell command is equivalent to the following shell pipeline:";
+        `Pre "sha256sum | xxd -r -p | base64 | tr -d \"=\"";
+        `P "but does not need each individual command to be available.";
+      ] @ common_man
+    in
+    Term.(ret (pure main $ pure ())),
+    Term.info "sha256-b64" ~doc ~man
+
+  let cmds = [sha256_b64_cmd]
+
+end
+
 let group_t =
   let doc = "Take group parameters from file $(docv)." in
   Arg.(value & opt (some file) None & info ["group"] ~docv:"GROUP" ~doc)
@@ -294,27 +326,28 @@ module Election : CMDLINER_MODULE = struct
 
   module MakeGetters (X : sig val dir : string end) = struct
 
-    let get_threshold () =
-      let file = "threshold.json" in
-      Printf.eprintf "I: loading %s...\n%!" file;
-      try Some (string_of_file (X.dir / file))
-      with _ -> None
-
-    let get_public_keys () =
-      load_from_file (fun x -> x) (X.dir/"public_keys.jsons") |>
-      option_map Array.of_list
-
     let get_public_creds () =
       let file = "public_creds.txt" in
       Printf.eprintf "I: loading %s...\n%!" file;
-      try Some (lines_of_file (X.dir / file))
-      with _ -> None
+      try Some (lines_of_file (X.dir / file)) with _ -> None
+
+    let get_trustees () =
+      let file = "trustees.json" in
+      Printf.eprintf "I: loading %s...\n%!" file;
+      try Some (string_of_file (X.dir / file)) with _ -> None
 
     let get_ballots () =
       let file = "ballots.jsons" in
       Printf.eprintf "I: loading %s...\n%!" file;
-      try Some (lines_of_file (X.dir / file))
-      with _ -> None
+      try Some (lines_of_file (X.dir / file)) with _ -> None
+
+    let get_shuffles () =
+      let file = "shuffles.jsons" in
+      if Sys.file_exists (X.dir / file) then (
+        Printf.eprintf "I: loading %s...\n%!" file;
+        try Some (lines_of_file (X.dir / file))
+        with _ -> None
+      ) else None
 
     let get_result () =
       load_from_file (fun x -> x) (X.dir/"result.json") |> function
@@ -344,10 +377,10 @@ module Election : CMDLINER_MODULE = struct
         | Some u ->
            if not (
              download dir u "election.json" &&
-             download dir u "public_keys.jsons" &&
+             download dir u "trustees.json" &&
              download dir u "public_creds.txt" &&
-             download dir u "ballots.jsons" &&
-             download dir u "result.json"
+             (download dir u "ballots.jsons" || true) &&
+             (download dir u "result.json" || download dir u "shuffles.jsons" || true)
            ) then
              Printf.eprintf "W: some errors occurred while downloading\n%!";
       in
@@ -375,6 +408,7 @@ module Election : CMDLINER_MODULE = struct
         in
         print_endline (X.vote (Some privcred) ballot)
       | `Decrypt privkey ->
+        X.verify ();
         let privkey =
           match load_from_file (fun x -> x) privkey with
           | Some [privkey] -> privkey
@@ -386,17 +420,25 @@ module Election : CMDLINER_MODULE = struct
          let pdk = string_of_file pdk in
          print_endline (X.tdecrypt key pdk)
       | `Verify -> X.verify ()
-      | `Finalize ->
+      | `Validate ->
         let factors =
           let fname = dir/"partial_decryptions.jsons" in
           match load_from_file (fun x -> x) fname with
           | Some factors -> factors
           | None -> failwith "cannot load partial decryptions"
         in
+        let result = X.validate factors in
         let oc = open_out (dir/"result.json") in
-        output_string oc (X.finalize factors);
+        output_string oc result;
         output_char oc '\n';
         close_out oc
+      | `Shuffle ->
+         let s = X.shuffle_ciphertexts () in
+         print_endline s
+      | `Checksums ->
+         X.checksums () |> print_endline
+      | `ComputeVoters privcreds ->
+         X.compute_voters privcreds |> List.iter print_endline
       end;
       if cleanup then rm_rf dir
     )
@@ -421,6 +463,11 @@ module Election : CMDLINER_MODULE = struct
     let the_info = Arg.info ["decryption-key"] ~docv:"KEY" ~doc in
     Arg.(value & opt (some file) None the_info)
 
+  let privcreds_t =
+    let doc = "Read private credentials from file $(docv)." in
+    let the_info = Arg.info ["privcreds"] ~docv:"PRIVCREDS" ~doc in
+    Arg.(value & opt (some file) None the_info)
+
   let vote_cmd =
     let doc = "create a ballot" in
     let man = [
@@ -469,17 +516,68 @@ module Election : CMDLINER_MODULE = struct
     Term.(ret (main $ url_t $ optdir_t $ key_t $ pdk_t)),
     Term.info "threshold-decrypt" ~doc ~man:decrypt_man
 
-  let finalize_cmd =
-    let doc = "finalizes an election" in
+  let validate_cmd =
+    let doc = "validates an election" in
     let man = [
       `S "DESCRIPTION";
       `P "This command reads partial decryptions done by trustees from file $(i,partial_decryptions.jsons), checks them, combines them into the final tally and prints the result to standard output.";
       `P "The result structure contains partial decryptions itself, so $(i,partial_decryptions.jsons) can be discarded afterwards.";
     ] @ common_man in
-    Term.(ret (pure main $ url_t $ optdir_t $ pure `Finalize)),
-    Term.info "finalize" ~doc ~man
+    Term.(ret (pure main $ url_t $ optdir_t $ pure `Validate)),
+    Term.info "validate" ~doc ~man
 
-  let cmds = [vote_cmd; verify_cmd; decrypt_cmd; tdecrypt_cmd; finalize_cmd]
+  let shuffle_cmd =
+    let doc = "shuffle ciphertexts" in
+    let man = [
+        `S "DESCRIPTION";
+        `P "This command shuffles non-homomorphic ciphertexts and prints on standard output the shuffle proof and the shuffled ciphertexts.";
+      ] @ common_man
+    in
+    Term.(ret (pure main $ url_t $ optdir_t $ pure `Shuffle)),
+    Term.info "shuffle" ~doc ~man
+
+  let checksums_cmd =
+    let doc = "compute checksums" in
+    let man = [
+        `S "DESCRIPTION";
+        `P "This command computes checksums needed to audit an election.";
+      ] @ common_man
+    in
+    Term.(ret (pure main $ url_t $ optdir_t $ pure `Checksums)),
+    Term.info "checksums" ~doc ~man
+
+  let compute_voters_cmd =
+    let doc = "compute actual voters" in
+    let man = [
+        `S "DESCRIPTION";
+        `P "This command computes the list of voters that actually voted in an election, from the list of ballots and private credentials.";
+      ] @ common_man
+    in
+    let main =
+      Term.pure
+        (fun u d privcreds ->
+          let privcreds =
+            get_mandatory_opt "--privcreds" privcreds
+            |> lines_of_file
+            |> stream_to_list
+          in
+          main u d (`ComputeVoters privcreds)
+        )
+    in
+    Term.(ret (main $ url_t $ optdir_t $ privcreds_t)),
+    Term.info "compute-voters" ~doc ~man
+
+  let cmds =
+    [
+      vote_cmd;
+      verify_cmd;
+      decrypt_cmd;
+      tdecrypt_cmd;
+      validate_cmd;
+      shuffle_cmd;
+      checksums_cmd;
+      compute_voters_cmd;
+    ]
 
 end
 
@@ -488,7 +586,6 @@ module Credgen : CMDLINER_MODULE = struct
 
   let params_priv = "private credentials with ids", ".privcreds", 0o400
   let params_pub = "public credentials", ".pubcreds", 0o444
-  let params_hash = "hashed public credentials with ids", ".hashcreds", 0o400
 
   let save (info, ext, perm) basename things =
     let fname = basename ^ ext in
@@ -524,18 +621,15 @@ module Credgen : CMDLINER_MODULE = struct
       | `Derive c ->
         print_endline (R.derive c)
       | `Generate ids ->
-        let privs, pubs, hashs =
-          List.fold_left (fun (privs, pubs, hashs) id ->
-            let priv, pub, hash = R.generate () in
-            let priv = id ^ " " ^ priv and hash = id ^ " " ^ hash in
-            priv::privs, pub::pubs, hash::hashs
-          ) ([], [], []) ids
+        let privs, pubs = R.generate ids in
+        let privs =
+          List.combine ids privs
+          |> List.map (fun (id, priv) -> id ^ " " ^ priv)
         in
         let timestamp = Printf.sprintf "%.0f" (Unix.time ()) in
         let base = dir / timestamp in
-        save params_priv base (List.rev privs);
-        save params_pub base (List.sort compare pubs);
-        save params_hash base (List.rev hashs)
+        save params_priv base privs;
+        save params_pub base pubs
     )
 
   let count_t =
@@ -544,7 +638,7 @@ module Credgen : CMDLINER_MODULE = struct
     Arg.(value & opt (some int) None the_info)
 
   let file_t =
-    let doc = "Read identities from $(docv) and generate an additional $(i,T.hashcreds) with identities associated with hashed public credentials. These hashed public credentials are used by the hotline to update a public credential on the web server. One credential will be generated for each line of $(docv)." in
+    let doc = "Read identities from $(docv). One credential will be generated for each line of $(docv)." in
     let the_info = Arg.info ["file"] ~docv:"FILE" ~doc in
     Arg.(value & opt (some file) None the_info)
 
@@ -566,6 +660,53 @@ module Credgen : CMDLINER_MODULE = struct
 
 end
 
+module Mktrustees : CMDLINER_MODULE = struct
+  let main dir =
+    wrap_main
+      (fun () ->
+        let get_public_keys () =
+          Some (lines_of_file (dir / "public_keys.jsons") |> stream_to_list)
+        in
+        let get_threshold () =
+          let fn = dir / "threshold.json" in
+          if Sys.file_exists fn then Some (string_of_file fn) else None
+        in
+        let get_trustees () =
+          match get_threshold () with
+          | Some t ->
+             t
+             |> threshold_parameters_of_string Yojson.Safe.read_json
+             |> (fun x -> [`Pedersen x])
+             |> string_of_trustees Yojson.Safe.write_json
+          | None ->
+             match get_public_keys () with
+             | None -> failwith "trustees are missing"
+             | Some t ->
+                t
+                |> List.map (trustee_public_key_of_string Yojson.Safe.read_json)
+                |> List.map (fun x -> `Single x)
+                |> string_of_trustees Yojson.Safe.write_json
+        in
+        let trustees = get_trustees () in
+        let oc = open_out (dir / "trustees.json") in
+        output_string oc trustees;
+        output_char oc '\n';
+        close_out oc
+      )
+
+  let mktrustees_cmd =
+    let doc = "create a trustee parameter file" in
+    let man = [
+      `S "DESCRIPTION";
+      `P "This command reads $(i,public_keys.jsons) (or $(i,threshold.json) if it exists). It then generates an $(i,trustees.json) file.";
+    ] @ common_man in
+    Term.(ret (pure main $ dir_t)),
+    Term.info "mktrustees" ~doc ~man
+
+  let cmds = [mktrustees_cmd]
+
+end
+
 module Mkelection : CMDLINER_MODULE = struct
   open Tool_mkelection
 
@@ -575,11 +716,12 @@ module Mkelection : CMDLINER_MODULE = struct
         let group = get_mandatory_opt "--group" group |> string_of_file
         let uuid = get_mandatory_opt "--uuid" uuid
         let template = get_mandatory_opt "--template" template |> string_of_file
-        let get_public_keys () =
-          Some (lines_of_file (dir / "public_keys.jsons") |> stream_to_list |> Array.of_list)
-        let get_threshold () =
-          let fn = dir / "threshold.json" in
-          if Sys.file_exists fn then Some (string_of_file fn) else None
+        let get_trustees () =
+          let fn = dir / "trustees.json" in
+          if Sys.file_exists fn then
+            string_of_file fn
+          else
+            failwith "trustees are missing"
       end in
       let module R = (val make (module P : PARAMS) : S) in
       let params = R.mkelection () in
@@ -637,7 +779,18 @@ module Verifydiff : CMDLINER_MODULE = struct
 
 end
 
-let cmds = Tkeygen.cmds @ Ttkeygen.cmds @ Election.cmds @ Credgen.cmds @ Mkelection.cmds @ Verifydiff.cmds
+let cmds =
+  List.flatten
+    [
+      Shasum.cmds;
+      Tkeygen.cmds;
+      Ttkeygen.cmds;
+      Election.cmds;
+      Credgen.cmds;
+      Mktrustees.cmds;
+      Mkelection.cmds;
+      Verifydiff.cmds;
+    ]
 
 let default_cmd =
   let open Belenios_version in
