@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -19,6 +19,8 @@
 (*  <http://www.gnu.org/licenses/>.                                       *)
 (**************************************************************************)
 
+open Js_of_ocaml
+open Js_of_ocaml_lwt
 open Platform
 open Serializable_j
 open Common
@@ -27,8 +29,6 @@ open Tool_js_common
 let election = ref None
 let encrypted_tally = ref None
 
-let ( >>= ) = Js.Opt.bind
-
 let wrap f x =
   (try
      Js.Opt.case (f x)
@@ -47,8 +47,8 @@ let basic_check_private_key s =
     if i < n then
       match s.[i] with
       | '"' -> middle (i+1)
-      | _ -> failwith "Must start with a double quote"
-    else failwith "Too short"
+      | _ -> failwith "Must start with a double quote (character given was another character)"
+    else failwith "Must start with a double quote (empty string given)"
   and middle i =
     if i < n then
       match s.[i] with
@@ -73,54 +73,76 @@ let compute_partial_decryption _ =
   let encrypted_tally = encrypted_tally_of_string P.G.read e in
   document##getElementById (Js.string "private_key") >>= fun e ->
   Dom_html.CoerceTo.input e >>= fun e ->
-  let pk_str = Js.to_string e##value in
+  let pk_str = Js.to_string e##.value in
   let private_key =
-    try
-      let epk = get_textarea "encrypted_private_key" in
-      let module PKI = Trustees.MakePKI (P.G) (DirectRandom) in
-      let module C = Trustees.MakeChannels (P.G) (DirectRandom) (PKI) in
-      let sk = PKI.derive_sk pk_str and dk = PKI.derive_dk pk_str in
-      let vk = P.G.(g **~ sk) in
-      let epk = C.recv dk vk epk in
-      (partial_decryption_key_of_string epk).pdk_decryption_key
-    with Not_found ->
-      basic_check_private_key pk_str;
-      try number_of_string pk_str
-      with e ->
-        Printf.ksprintf
-          failwith "Error in format of private key: %s" (Printexc.to_string e)
+    match get_textarea_opt "encrypted_private_key" with
+    | Some epk ->
+       let module PKI = Trustees.MakePKI (P.G) (DirectRandom) in
+       let module C = Trustees.MakeChannels (P.G) (DirectRandom) (PKI) in
+       let sk = PKI.derive_sk pk_str and dk = PKI.derive_dk pk_str in
+       let vk = P.G.(g **~ sk) in
+       let epk = C.recv dk vk epk in
+       (partial_decryption_key_of_string epk).pdk_decryption_key
+    | None ->
+       basic_check_private_key pk_str;
+       try number_of_string pk_str with
+       | e ->
+         Printf.ksprintf
+           failwith "Error in format of private key: %s" (Printexc.to_string e)
   in
   let factor = E.compute_factor encrypted_tally private_key in
   set_textarea "pd" (string_of_partial_decryption P.G.write factor);
-  Js.some ()
+  return_unit
 
 let compute_hash () =
-  let _ =
-    Js.Opt.option !encrypted_tally >>= fun e ->
-    let hash = sha256_b64 e in
-    document##getElementById (Js.string "hash") >>= fun e ->
-    let t = document##createTextNode (Js.string hash) in
-    Dom.appendChild e t;
-    Js.null
-  in Js._false
+  Js.Opt.option !encrypted_tally >>== fun e ->
+  let hash = sha256_b64 e in
+  document##getElementById (Js.string "hash") >>== fun e ->
+  let t = document##createTextNode (Js.string hash) in
+  Dom.appendChild e t
+
+let load_private_key_file _ =
+  document##getElementById (Js.string "private_key_file") >>= fun e ->
+  Dom_html.CoerceTo.input e >>= fun e ->
+  Js.Opt.option (Js.Optdef.to_option (e##.files)) >>= fun e ->
+  e##item (0) >>= fun file ->
+  let reader = new%js File.fileReader in
+  reader##.onload :=
+    Dom.handler (fun _ ->
+        let () =
+          document##getElementById (Js.string "private_key") >>== fun e ->
+          Dom_html.CoerceTo.input e >>== fun e ->
+          File.CoerceTo.string (reader##.result) >>== fun text ->
+          e##.value := text
+        in Js._false
+      );
+  reader##readAsText (file);
+  return_unit
 
 let main _ =
-  let _ =
-    document##getElementById (Js.string "compute") >>= fun e ->
-    Dom_html.CoerceTo.button e >>= fun e ->
-    e##onclick <- Dom_html.handler (wrap compute_partial_decryption);
-    Js.null
+  let () =
+    document##getElementById (Js.string "compute") >>== fun e ->
+    Dom_html.CoerceTo.button e >>== fun e ->
+    e##.onclick := Dom_html.handler (wrap compute_partial_decryption)
   in
-  let _ =
-    Lwt.async (fun () ->
-      let open XmlHttpRequest in
-      lwt e = get "../encrypted_tally.json" in
-      encrypted_tally := Some e.content;
-      lwt e = get "../election.json" in
-      election := Some e.content;
-      Lwt.return (compute_hash ()))
+  let () =
+    document##getElementById (Js.string "private_key_file") >>== fun e ->
+    Dom_html.CoerceTo.input e >>== fun e ->
+    e##.onchange := Dom_html.handler (wrap load_private_key_file)
   in
-  Js._false
+  let () =
+    match List.assoc_opt "uuid" (get_params ()) with
+    | None -> ()
+    | Some uuid ->
+       Lwt.async (fun () ->
+           let open Js_of_ocaml_lwt.XmlHttpRequest in
+           let%lwt e = get ("../elections/" ^ uuid ^ "/encrypted_tally.json") in
+           encrypted_tally := Some (String.trim e.content);
+           let%lwt e = get ("../elections/" ^ uuid ^ "/election.json") in
+           election := Some e.content;
+           Lwt.return (compute_hash ())
+         )
+  in Js._false
 
 let () =
-  Dom_html.window##onload <- Dom_html.handler main
+  Dom_html.window##.onload := Dom_html.handler main
