@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -50,16 +50,17 @@ module Make (P : PARSED_PARAMS) : S = struct
   (* Generate key *)
 
   module KG = Trustees.MakeSimple (G) (DirectRandom)
+  module K = Trustees.MakeCombinator (G)
 
   type keypair = { id : string; priv : string; pub : string }
 
   let trustee_keygen () =
     let private_key = KG.generate () in
     let public_key = KG.prove private_key in
-    assert (KG.check public_key);
+    assert (K.check [`Single public_key]);
     let id = String.sub
       (sha256_hex (G.to_string public_key.trustee_public_key))
-      0 8 |> String.uppercase
+      0 8 |> String.uppercase_ascii
     in
     let priv = string_of_number private_key in
     let pub = string_of_trustee_public_key G.write public_key in
