@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -31,9 +31,10 @@ let stream_to_list s =
 let lines_of_file fname =
   let ic = open_in fname in
   Stream.from (fun _ ->
-    try Some (input_line ic)
-    with End_of_file -> close_in ic; None
-  )
+      match input_line ic with
+      | line -> Some line
+      | exception End_of_file -> close_in ic; None
+    )
 
 let string_of_file f =
   lines_of_file f |> stream_to_list |> String.concat "\n"
@@ -50,16 +51,13 @@ let ( / ) = Filename.concat
 
 type verifydiff_error =
   | ElectionMismatch
-  | PublicKeysMismatch
-  | MissingPublicKeys
-  | InvalidPublicKeys
-  | InvalidThreshold
+  | MissingTrustees
+  | InvalidTrustees
   | PublicKeyMismatch
-  | ThresholdMismatch
+  | TrusteesMismatch
   | MissingCredentials
   | InvalidCredential
   | CredentialsMismatch
-  | MissingBallots
   | InvalidBallot
   | DuplicateBallot
   | BallotSignedByInvalidKey
@@ -70,16 +68,13 @@ exception VerifydiffError of verifydiff_error
 
 let explain_error = function
   | ElectionMismatch -> "election mismatch"
-  | PublicKeysMismatch -> "public keys mismatch"
-  | MissingPublicKeys -> "missing public keys"
-  | InvalidPublicKeys -> "invalid public keys"
-  | InvalidThreshold -> "invalid threshold parameters"
+  | MissingTrustees -> "missing trustees"
+  | InvalidTrustees -> "invalid trustees"
   | PublicKeyMismatch -> "public key mismatch"
-  | ThresholdMismatch -> "threshold parameters mismatch"
+  | TrusteesMismatch -> "trustees mismatch"
   | MissingCredentials -> "missing credentials"
   | InvalidCredential -> "invalid credential"
   | CredentialsMismatch -> "credentials mismatch"
-  | MissingBallots -> "missing ballots"
   | InvalidBallot -> "invalid ballot"
   | DuplicateBallot -> "duplicate ballot"
   | BallotSignedByInvalidKey -> "ballot signed by invalid key"
@@ -91,6 +86,11 @@ let () =
       | VerifydiffError e -> Some ("verify-diff error: " ^ explain_error e)
       | _ -> None)
 
+let load_trustees dir =
+  match string_of_file_opt (dir / "trustees.json") with
+  | Some t -> t
+  | None -> raise (VerifydiffError MissingTrustees)
+
 let verifydiff dir1 dir2 =
   (* the elections must be the same *)
   let election = string_of_file (dir1 / "election.json") in
@@ -98,42 +98,20 @@ let verifydiff dir1 dir2 =
     let election2 = string_of_file (dir2 / "election.json") in
     if election2 <> election then raise (VerifydiffError ElectionMismatch)
   in
-  (* the public keys must be the same *)
-  let pks = load_from_file (fun x -> x) (dir1 / "public_keys.jsons") in
+  (* the trustees must be the same *)
+  let trustees = load_trustees dir1 in
   let () =
-    let pks2 = load_from_file (fun x -> x) (dir2 / "public_keys.jsons") in
-    if pks2 <> pks then raise (VerifydiffError PublicKeysMismatch)
+    let trustees2 = load_trustees dir2 in
+    if trustees2 <> trustees then raise (VerifydiffError TrusteesMismatch)
   in
-  (* the threshold parameters must be the same *)
-  let threshold = string_of_file_opt (dir1 / "threshold.json") in
-  let () =
-    let t2 = string_of_file_opt (dir2 / "threshold.json") in
-    if t2 <> threshold then raise (VerifydiffError ThresholdMismatch)
-  in
-  (* the public keys / threshold parameters must be valid *)
   let module ED = (val Election.(get_group (of_string election))) in
   let open ED in
   let module E = Election.Make (ED) (DirectRandom) in
-  let y =
-    match threshold with
-    | None ->
-       let module K = Trustees.MakeSimple (G) (DirectRandom) in
-       let pks = match pks with
-         | None -> raise (VerifydiffError MissingPublicKeys)
-         | Some pks -> List.map (trustee_public_key_of_string G.read) pks
-       in
-       if not (List.for_all K.check pks) then
-         raise (VerifydiffError InvalidPublicKeys);
-       K.combine (Array.of_list pks)
-    | Some t ->
-       let t = threshold_parameters_of_string G.read t in
-       let module P = Trustees.MakePKI (G) (DirectRandom) in
-       let module C = Trustees.MakeChannels (G) (DirectRandom) (P) in
-       let module K = Trustees.MakePedersen (G) (DirectRandom) (P) (C) in
-       if not (K.check t) then
-         raise (VerifydiffError InvalidThreshold);
-       K.combine t
-  in
+  let trustees = trustees_of_string G.read trustees in
+  let module K = Trustees.MakeCombinator (G) in
+  if not (K.check trustees) then
+    raise (VerifydiffError InvalidTrustees);
+  let y = K.combine_keys trustees in
   (* the public keys must correspond to the public key of election *)
   let () =
     if not G.(election.e_params.e_public_key =~ y) then
@@ -170,7 +148,7 @@ let verifydiff dir1 dir2 =
   let module GMap = Map.Make (G) in
   let ballots dir =
     match load_from_file (ballot_of_string G.read) (dir / "ballots.jsons") with
-    | None -> raise (VerifydiffError MissingBallots)
+    | None -> GMap.empty
     | Some ballots ->
        if not (List.for_all E.check_ballot ballots) then
          raise (VerifydiffError InvalidBallot);
