@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -20,36 +20,35 @@
 (**************************************************************************)
 
 open Signatures
+open Serializable_t
+open Web_serializable_builtin_t
 open Web_serializable_t
 
-val spool_dir : string ref
-val server_mail : string ref
-val return_path : string option ref
-val contact_uri : string option ref
-val gdpr_uri : string ref
-
 module LwtRandom : RANDOM with type 'a t = 'a Lwt.t
 (** Lwt-compatible random number generation. *)
 
-type error =
-  | Serialization of exn
-  | ProofCheck
-  | ElectionClosed
-  | MissingCredential
-  | InvalidCredential
-  | RevoteNotAllowed
-  | ReusedCredential
-  | WrongCredential
-  | UsedCredential
-  | CredentialNotFound
-  | UnauthorizedVoter
+type cast_error =
+  | ECastSerialization of exn
+  | ECastMissingCredential
+  | ECastInvalidCredential
+  | ECastProofCheck
+  | ECastWrongCredential
+  | ECastRevoteNotAllowed
+  | ECastReusedCredential
 
-exception Error of error
+type error =
+  | ElectionClosed
+  | UnauthorizedVoter
+  | CastError of cast_error
+
+exception BeleniosWebError of error
 
 val fail : error -> 'a Lwt.t
 
 val explain_error : (module Web_i18n_sig.LocalizedStrings) -> error -> string
 
+val format_period : (module Web_i18n_sig.LocalizedStrings) -> period -> string
+
 val open_security_log : string -> unit Lwt.t
 (** Set the path to the security logger. *)
 
@@ -64,14 +63,14 @@ val set_rewrite_prefix : src:string -> dst:string -> unit
 
 type election_file =
   | ESRaw
-  | ESKeys
-  | ESTParams
+  | ESTrustees
   | ESCreds
   | ESBallots
   | ESVoters
   | ESRecords
   | ESETally
   | ESResult
+  | ESShuffles
 
 val election_file_of_string : string -> election_file
 val string_of_election_file : election_file -> string
@@ -88,12 +87,43 @@ val uuid :
    [ `One of uuid ] Eliom_parameter.param_name)
   Eliom_parameter.params_type
 
+type site_cont =
+  | ContSiteHome
+  | ContSiteAdmin
+  | ContSiteElection of uuid
+
+val site_cont :
+  string ->
+  (site_cont, [ `WithoutSuffix ],
+   [ `One of site_cont ] Eliom_parameter.param_name)
+  Eliom_parameter.params_type
+
+type privacy_cont =
+  | ContAdmin
+  | ContSignup of string
+
+val privacy_cont :
+  string ->
+  (privacy_cont, [ `WithoutSuffix ],
+   [ `One of privacy_cont ] Eliom_parameter.param_name)
+  Eliom_parameter.params_type
+
+type captcha_error =
+  | BadCaptcha
+  | BadAddress
+
+type add_account_error =
+  | UsernameTaken
+  | AddressTaken
+  | BadUsername
+  | BadPassword of string
+  | PasswordMismatch
+  | BadSpaceInPassword
+
 val generate_token : ?length:int -> unit -> string Lwt.t
 
 val string_of_user : user -> string
 
-val underscorize : uuid -> string
-
 val send_email : string -> string -> string -> unit Lwt.t
 
 val split_identity : string -> string * string
@@ -103,9 +133,41 @@ val get_languages : string list option -> string list
 val string_of_languages : string list option -> string
 val languages_of_string : string -> string list
 
-val is_email : string -> bool
+val pcre_exec_opt : rex:Pcre.regexp -> string -> Pcre.substrings option
 
+val is_email : string -> bool
+val extract_email : string -> string option
+
+val file_exists : string -> bool Lwt.t
 val read_file : ?uuid:uuid -> string -> string list option Lwt.t
 val write_file : ?uuid:uuid -> string -> string list -> unit Lwt.t
 
+val cleanup_file : string -> unit Lwt.t
+val rmdir : string -> unit Lwt.t
+
+val urlize : string -> string
+val unurlize : string -> string
+
+val webize_trustee_public_key : 'a trustee_public_key -> 'a web_trustee_public_key
+val unwebize_trustee_public_key : 'a web_trustee_public_key -> 'a trustee_public_key
+
+val get_suitable_group_kind : template -> [ `H | `NH ]
+val is_group_fixed : draft_election -> bool
+
 val default_contact : string
+val default_questions : question array
+val default_name : string
+val default_description : string
+
+val default_creation_date : datetime
+val default_validation_date : datetime
+val default_tally_date : datetime
+val default_archive_date : datetime
+
+val days_to_archive : int
+val days_to_delete : int
+val days_to_mail : int
+val days_between_mails : int
+val days_to_publish_result : int
+
+val max_election_name_size : int
