@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -36,6 +36,9 @@ module type LocalizedStrings = sig
   val invalid_cred : string
   val input_credential : string
   val answer_to_questions : string
+  val warning_0_255 : string
+  val alert_0_255 : string
+  val at_least_one_invalid : string
   val review_and_encrypt : string
   val authenticate : string
   val confirm : string
@@ -81,7 +84,6 @@ module type LocalizedStrings = sig
   val audit_data : string
   val parameters : string
   val public_credentials : string
-  val trustee_public_keys : string
   val ballots : string
   val election_server : string
   val accepted_ballots : string
@@ -95,6 +97,7 @@ module type LocalizedStrings = sig
   val password_login : string
   val by_using_you_accept : string
   val privacy_policy : string
+  val privacy_policy_short : string
   val accept : string
   val not_yet_open : string
   val come_back_later : string
@@ -102,16 +105,25 @@ module type LocalizedStrings = sig
   val please_enable_them : string
   val election_currently_closed : string
   val election_closed_being_tallied : string
-  val the : string
-  val encrypted_tally : string
-  val hash_is : string
   val election_has_been_tallied : string
   val election_archived : string
   val number_accepted_ballots : string
   val you_can_also_download : string
   val result_with_crypto_proofs : string
+  val the_raw_results : string
+  val json_result : string
+  val it_contains_all_clear : string
   val blank_vote : string
   val no_other_blank : string
+  val it_will_open_in : string
+  val the_election_will_close_in : string
+  val years : string
+  val months : string
+  val days : string
+  val hours : string
+  val minutes : string
+  val seconds : string
+  val result_currently_not_public : (string -> 'f, 'b, 'c, 'e, 'e, 'f) format6
   val mail_password_subject : (string -> 'f, 'b, 'c, 'e, 'e, 'f) format6
   val mail_password : (string -> string -> string -> string -> string -> 'f, 'b, 'c, 'e, 'e, 'f) format6
   val mail_credential_subject : (string -> 'f, 'b, 'c, 'e, 'e, 'f) format6
@@ -130,7 +142,5 @@ module type LocalizedStrings = sig
   val error_RevoteNotAllowed : string
   val error_ReusedCredential : string
   val error_WrongCredential : string
-  val error_UsedCredential : string
-  val error_CredentialNotFound : string
   val error_UnauthorizedVoter : string
 end
