@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -25,7 +25,7 @@ let advanced_mode = "Erweiterter Modus"
 let see_accepted_ballots = "angenommene Stimmen anzeigen"
 let belenios_booth = "Belenios Wahlkabine"
 let here = "hier"
-let question_header = "Frage #%d von %d — wählen Sie zwischen %d und %d Antworten aus"
+let question_header = "Wählen Sie zwischen %d und %d Antworten aus"
 let at_least = "Sie müssen mindestens %d Antworten auswählen"
 let at_most = "Sie müssen maximal %d Antworten auswählen"
 let previous = "Zurück"
@@ -35,6 +35,9 @@ let enter_cred = "Bitte geben Sie Ihre Wählernummer ein:"
 let invalid_cred = "Falsche Wählernummer!"
 let input_credential = "Wählernummer eingeben"
 let answer_to_questions = "Fragen beantworten"
+let warning_0_255 = "Warning: the system will accept any integer between 0 and 255 but, according to the election rules, invalid ballots (score too high or candidates not properly ranked) will be rejected at the end of the election."
+let alert_0_255 = "Value must be an integer between 0 and 255."
+let at_least_one_invalid = "At least one of the answers is invalid!"
 let review_and_encrypt = "Überprüfen und verschlüsseln"
 let authenticate = "Authentifizieren"
 let confirm = "Bestätigen"
@@ -59,11 +62,11 @@ let election_fingerprint = "Fingerabdruck der Abstimmung: "
 let i_am = "Ich bin "
 let and_ = " und "
 let i_cast_my_vote = "ich schicke meine Stimme ab"
-let please_login_to_confirm = "Bitte melden Sie sich an um Ihre Stime zu bestätigen."
+let please_login_to_confirm = "Bitte melden Sie sich an um Ihre Stimme zu bestätigen."
 let your_ballot_for = "Ihre Stimme für "
 let has_been_received = " wurde empfangen, aber noch nicht gespeichert. "
 let nobody_can_see = "Hinweis: Ihre Stimme ist verschlüsselt und niemand kann ihren Inhalt sehen."
-let you_have_already_voted = "Note: you have already voted. Your vote will be replaced."
+let you_have_already_voted = "Hinweis: Sie haben schon abgestimmt. Ihre vorherige Stimme wird ersetzt."
 let go_back_to_election = "Zurück zur Wahl"
 let has_been_accepted = " wurde angenommen."
 let you_can_check_its_presence = "Sie können jederzeit überprüfen, dass Ihre Stimme in der "
@@ -80,7 +83,6 @@ let get_the_source_code = "Den Quellcode herunterladen"
 let audit_data = "Auditdaten: "
 let parameters = "Parameter"
 let public_credentials = "Öffentliche Daten"
-let trustee_public_keys = "Öffentliche Schlüssel der Treuhänder"
 let ballots = "Stimmen"
 let election_server = "Wahlserver"
 let accepted_ballots = "Angenommene Stimmen"
@@ -92,8 +94,9 @@ let username = "Benutzername:"
 let password = "Passwort:"
 let login = "Login"
 let password_login = "Login mit Passwort"
-let by_using_you_accept = "By using this site, you accept our "
-let privacy_policy = "personal data policy"
+let by_using_you_accept = "Wenn Sie diese Seite benutzen akzeptieren sie unsere "
+let privacy_policy = "Datenschutzbestimmungen"
+let privacy_policy_short = "Datenschutzbestimmungen"
 let accept = "Bestätigen"
 let not_yet_open = "Entschuldigung, die Abstimmung ist noch nicht geöffnet."
 let come_back_later = "Diese Abstimmung gibt es noch nicht. Bitte kommen Sie später wieder."
@@ -101,16 +104,25 @@ let cookies_are_blocked = "Cookies sind deaktiviert"
 let please_enable_them = "Ihr Browser nimmt keine Cookies an, bitte aktivieren Sie diese."
 let election_currently_closed = "Diese Abstimmung ist beendet."
 let election_closed_being_tallied = "Diese Abstimmung ist beendet und wird ausgezählt."
-let the = "Der Hash des "
-let encrypted_tally = "verschlüsselten Ergebnisses"
-let hash_is = " ist "
 let election_has_been_tallied = "Diese Abstimmung wurde ausgezählt."
 let election_archived = "Diese Abstimmung wurde archiviert."
 let number_accepted_ballots = "Anzahl angenommener Stimmen: "
 let you_can_also_download = "Sie können außerdem das "
-let result_with_crypto_proofs = "Ergbnis mit den kryptographischen Beweisen herunterladen"
+let result_with_crypto_proofs = "Ergebnis mit den kryptographischen Beweisen herunterladen"
+let the_raw_results = "The raw results can be viewed in the "
+let json_result = "JSON result"
+let it_contains_all_clear = ". It contains all submitted ballots in clear, in random order. It is up to you to apply your favorite counting method (e.g. Condorcet, STV, majority judgement)."
 let blank_vote = "ungültige Stimme"
 let no_other_blank = "Bei einer ungültigen Stimme sind keine anderen Auswahlmöglichkeiten vorhanden."
+let it_will_open_in = "Sie öffnet in "
+let the_election_will_close_in = "Die Abstimmung schließt in "
+let years = " Jahr(en)"
+let months = " Monat(en)"
+let days = " Tag(en)"
+let hours = " Stunde(n)"
+let minutes = " Minute(n)"
+let seconds = " Sekunde(n)"
+let result_currently_not_public : ('a, 'b, 'c, 'd, 'e, 'f) format6 = "Das Ergebnis dieser Abstimmung ist derzeit noch nicht verfügbar. Es wird in %s veröffentlicht."
 
 
 let mail_password_subject : ('a, 'b, 'c, 'd, 'e, 'f) format6 =
@@ -123,7 +135,7 @@ let mail_password : ('a, 'b, 'c, 'd, 'e, 'f) format6 =
 
 Am Ende der Mail finden Sie Ihren Benutzername und Ihr Passwort. Um
 abzustimmen benötigen sie außerdem noch Ihre Wählernummer, die Ihnen
-in einer seperaten Mail zugestellt wird. Obwohl Passwort und
+in einer separaten Mail zugestellt wird. Obwohl Passwort und
 Wählernummer ähnlich aussehen, erfüllen sie zwei verschiedene Zwecke:
 die Wählernummer wird für die Verschlüsselung Ihrer Stimme in der
 virtuellen Wahlkabine benötigt, mit dem Passwort können Sie
@@ -153,7 +165,7 @@ Sie können so oft abstimmen wie Sie wollen, nur die letzte Stimme zählt.%s"
 
 let mail_credential_password =
 "Am Ende der Mail finden Sie Ihre Wählernummer. Um abzustimmen
-benötigen sie außerdem noch Ihr Passwort, die Ihnen in einer seperaten
+benötigen sie außerdem noch Ihr Passwort, die Ihnen in einer separaten
 Mail zugestellt wird. Obwohl Passwort und Wählernummer ähnlich
 aussehen, erfüllen sie zwei verschiedene Zwecke: die Wählernummer wird
 für die Verschlüsselung Ihrer Stimme in der virtuellen Wahlkabine
@@ -187,17 +199,15 @@ Das Ergebnis wird auf der Website der Abstimmung veröffentlicht:
 
 -- \nBelenios"
 
-let this_vote_replaces = "\n\nThis vote replaces any previous vote."
-let please_contact = "To get more information, please contact:"
+let this_vote_replaces = "\n\nDiese Stimme ersetzt eine eventuelle vorherige Stimme."
+let please_contact = "Für mehr Informationen wenden Sie sich bitte an:"
 
-let error_Serialization : ('a, 'b, 'c, 'd, 'e, 'f) format6 = "your ballot has a syntax error (%s)"
-let error_ProofCheck = "some proofs failed verification"
-let error_ElectionClosed = "the election is closed"
-let error_MissingCredential = "a credential is missing"
-let error_InvalidCredential = "your credential is invalid"
-let error_RevoteNotAllowed = "you are not allowed to revote"
-let error_ReusedCredential = "your credential has already been used"
-let error_WrongCredential = "you are not allowed to vote with this credential"
-let error_UsedCredential = "the credential has already been used"
-let error_CredentialNotFound = "the credential has not been found"
-let error_UnauthorizedVoter = "you are not allowed to vote"
+let error_Serialization : ('a, 'b, 'c, 'd, 'e, 'f) format6 = "Ihre Stimme enthält einen Syntaxfehler (%s)"
+let error_ProofCheck = "Einige Beweise konnten nicht verifiziert werden"
+let error_ElectionClosed = "Die Abstimmung ist beendet"
+let error_MissingCredential = "Die Wählernummer fehlt"
+let error_InvalidCredential = "Ihre Wählernummer ist ungültig"
+let error_RevoteNotAllowed = "Sie dürfen nicht erneut abstimmen"
+let error_ReusedCredential = "Ihre Wählernummer wurde schon benutzt"
+let error_WrongCredential = "Sie dürfen nicht mit dieser Wählernummer abstimmen"
+let error_UnauthorizedVoter = "Sie dürfen nicht abstimmen"
