@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -25,7 +25,7 @@ let advanced_mode = "Advanced mode"
 let see_accepted_ballots = "See accepted ballots"
 let belenios_booth = "Belenios Booth"
 let here = "here"
-let question_header = "Question #%d of %d — select between %d and %d answer(s)"
+let question_header = "Select between %d and %d answer(s)"
 let at_least = "You must select at least %d answer(s)"
 let at_most = "You must select at most %d answer(s)"
 let previous = "Previous"
@@ -35,11 +35,14 @@ let enter_cred = "Please enter your credential:"
 let invalid_cred = "Invalid credential!"
 let input_credential = "Input credential"
 let answer_to_questions = "Answer to questions"
+let warning_0_255 = "Warning: the system will accept any integer between 0 and 255 but, according to the election rules, invalid ballots (score too high or candidates not properly ranked) will be rejected at the end of the election."
+let alert_0_255 = "Value must be an integer between 0 and 255."
+let at_least_one_invalid = "At least one of the answers is invalid!"
 let review_and_encrypt = "Review and encrypt"
 let authenticate = "Authenticate"
 let confirm = "Confirm"
 let done_ = "Done"
-let booth_step1 = "Step 1/6: Input your credential"
+let booth_step1 = "Step 1/6: Input credential"
 let booth_step2 = "Step 2/6: Answer to questions"
 let booth_step3 = "Step 3/6: Review and encrypt"
 let booth_step5 = "Step 5/6: Confirm"
@@ -80,7 +83,6 @@ let get_the_source_code = "Get the source code"
 let audit_data = "Audit data: "
 let parameters = "parameters"
 let public_credentials = "public credentials"
-let trustee_public_keys = "trustee public keys"
 let ballots = "ballots"
 let election_server = "Election server"
 let accepted_ballots = "Accepted ballots"
@@ -94,6 +96,7 @@ let login = "Login"
 let password_login = "Password login"
 let by_using_you_accept = "By using this site, you accept our "
 let privacy_policy = "personal data policy"
+let privacy_policy_short = "Privacy policy"
 let accept = "Accept"
 let not_yet_open = "Sorry, this election is not yet open"
 let come_back_later = "This election does not exist yet. Please come back later."
@@ -101,16 +104,25 @@ let cookies_are_blocked = "Cookies are blocked"
 let please_enable_them = "Your browser seems to block cookies. Please enable them."
 let election_currently_closed = "This election is currently closed."
 let election_closed_being_tallied = "The election is closed and being tallied."
-let the = " The "
-let encrypted_tally = "encrypted tally"
-let hash_is = " hash is "
 let election_has_been_tallied = "This election has been tallied."
 let election_archived = "This election is archived."
 let number_accepted_ballots = "Number of accepted ballots: "
 let you_can_also_download = "You can also download the "
 let result_with_crypto_proofs = "result with cryptographic proofs"
+let the_raw_results = "The raw results can be viewed in the "
+let json_result = "JSON result"
+let it_contains_all_clear = ". It contains all submitted ballots in clear, in random order. It is up to you to apply your favorite counting method (e.g. Condorcet, STV, majority judgement)."
 let blank_vote = "Blank vote"
 let no_other_blank = "No other choices are allowed when voting blank"
+let it_will_open_in = "It will open in "
+let the_election_will_close_in = "The election will close in "
+let years = " year(s)"
+let months = " month(s)"
+let days = " day(s)"
+let hours = " hour(s)"
+let minutes = " minute(s)"
+let seconds = " second(s)"
+let result_currently_not_public : ('a, 'b, 'c, 'd, 'e, 'f) format6 = "The result of this election is currently not publicly available. It will be in %s."
 
 
 let mail_password_subject : ('a, 'b, 'c, 'd, 'e, 'f) format6 =
@@ -196,6 +208,4 @@ let error_InvalidCredential = "your credential is invalid"
 let error_RevoteNotAllowed = "you are not allowed to revote"
 let error_ReusedCredential = "your credential has already been used"
 let error_WrongCredential = "you are not allowed to vote with this credential"
-let error_UsedCredential = "the credential has already been used"
-let error_CredentialNotFound = "the credential has not been found"
 let error_UnauthorizedVoter = "you are not allowed to vote"
