@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -25,7 +25,7 @@ let advanced_mode = "Mode avancé"
 let see_accepted_ballots = "Voir les bulletins acceptés"
 let belenios_booth = "Isoloir Belenios"
 let here = "ici"
-let question_header = "Question %d/%d — sélectionnez entre %d et %d réponse(s)"
+let question_header = "Sélectionnez entre %d et %d réponse(s)"
 let at_least = "Vous devez sélectionner au moins %d réponse(s)"
 let at_most = "Vous devez sélectionner au plus %d réponse(s)"
 let previous = "Précédent"
@@ -35,6 +35,9 @@ let enter_cred = "Veuillez entrer votre code de vote :"
 let invalid_cred = "Code de vote invalide !"
 let input_credential = "Saisie du code de vote"
 let answer_to_questions = "Réponse aux questions"
+let warning_0_255 = "Attention: le système accepte n'importe quel nombre entre 0 et 255 mais, selon les règles de l'élection, les bulletins invalides (score trop élevé ou candidats pas classés correctement) seront rejetés à la fin de l'élection."
+let alert_0_255 = "La valeur doit être un entier entre 0 et 255."
+let at_least_one_invalid = "Au moins une des réponses est incorrecte !"
 let review_and_encrypt = "Récapitulatif et chiffrement"
 let authenticate = "Authentification"
 let confirm = "Confirmation"
@@ -80,7 +83,6 @@ let get_the_source_code = "Obtenir le code source"
 let audit_data = "Données d'audit : "
 let parameters = "paramètres"
 let public_credentials = "clés de vérification"
-let trustee_public_keys = "clés publiques"
 let ballots = "bulletins"
 let election_server = "Serveur d'élections"
 let accepted_ballots = "Bulletins acceptés"
@@ -94,6 +96,7 @@ let login = "Se connecter"
 let password_login = "Connexion par mot de passe"
 let by_using_you_accept = "En utilisant ce site, vous acceptez notre "
 let privacy_policy = "politique concernant les données personnelles"
+let privacy_policy_short = "Politique de confidentialité"
 let accept = "Accepter"
 let not_yet_open = "Désolé, cette élection n'est pas encore ouverte"
 let come_back_later = "Cette élection n'existe pas encore. Veuillez revenir plus tard."
@@ -101,16 +104,25 @@ let cookies_are_blocked = "Les cookies sont bloqués"
 let please_enable_them = "Votre navigateur semble bloquer les cookies. Veuillez les activer."
 let election_currently_closed = "Cette élection est actuellement fermée."
 let election_closed_being_tallied = "L'élection est fermée et en cours de dépouillement."
-let the = " L'empreinte du "
-let encrypted_tally = "résultat chiffré"
-let hash_is = " est "
 let election_has_been_tallied = "Cette élection a été dépouillée."
 let election_archived = "Cette élection est archivée."
 let number_accepted_ballots = "Nombre de bulletins acceptés : "
 let you_can_also_download = "Vous pouvez également télécharger le "
 let result_with_crypto_proofs = "résultat avec les preuves cryptographiques"
+let the_raw_results = "Les résultats bruts peuvent être consultés dans le "
+let json_result = "résultat JSON"
+let it_contains_all_clear = ". Il contient tous les bulletins soumis en clair, dans un ordre aléatoire. C'est à vous d'appliquer votre méthode de comptage favorite (par exemple Condorcet, STV, jugement majoritaire)."
 let blank_vote = "Vote blanc"
 let no_other_blank = "Vous ne pouvez pas sélectionner d'autres choix lors d'un vote blanc"
+let it_will_open_in = "Elle ouvrira dans "
+let the_election_will_close_in = "L'élection fermera dans "
+let years = " année(s)"
+let months = " mois"
+let days = " jour(s)"
+let hours = " heure(s)"
+let minutes = " minute(s)"
+let seconds = " seconde(s)"
+let result_currently_not_public : ('a, 'b, 'c, 'd, 'e, 'f) format6 = "Le résultat de cette élection n'est actuellement pas public. Il le sera dans %s."
 
 
 let mail_password_subject : ('a, 'b, 'c, 'd, 'e, 'f) format6 =
@@ -199,6 +211,4 @@ let error_InvalidCredential = "votre code de vote est invalide"
 let error_RevoteNotAllowed = "vous n'êtes pas autorisé(e) à revoter"
 let error_ReusedCredential = "votre code de vote a déjà été utilisé"
 let error_WrongCredential = "vous n'êtes pas autorisé(e) à voter avec ce code de vote"
-let error_UsedCredential = "le code de vote a déjà été utilisé"
-let error_CredentialNotFound = "le code de vote n'a pas été trouvé"
 let error_UnauthorizedVoter = "vous n'êtes pas autorisé(e) a voter"
