@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -25,7 +25,7 @@ let advanced_mode = "Modo avanzato"
 let see_accepted_ballots = "Consultare le schede elettorali accettate"
 let belenios_booth = "Cabina elettorale Belenios"
 let here = "qui"
-let question_header = "Domanda %d/%d — selezionare tra %d e %d risposta(e)"
+let question_header = "Selezionare tra %d e %d risposta(e)"
 let at_least = "Lei deve selezionare almeno %d risposta(e)"
 let at_most = "Lei deve selezionare al massimo %d risposta(e)"
 let previous = "Precedente"
@@ -35,6 +35,9 @@ let enter_cred = "Si prega di inserire il codice di voto :"
 let invalid_cred = "Codice di voto non valido !"
 let input_credential = "Inserire il codice di voto"
 let answer_to_questions = "Risposta alle domande"
+let warning_0_255 = "Warning: the system will accept any integer between 0 and 255 but, according to the election rules, invalid ballots (score too high or candidates not properly ranked) will be rejected at the end of the election."
+let alert_0_255 = "Value must be an integer between 0 and 255."
+let at_least_one_invalid = "At least one of the answers is invalid!"
 let review_and_encrypt = "Riepilogo e cifratura"
 let authenticate = "Autenticazione"
 let confirm = "Conferma"
@@ -80,7 +83,6 @@ let get_the_source_code = "Ottenere il codice sorgente"
 let audit_data = "Dati d'audit : "
 let parameters = "parametri"
 let public_credentials = "chiavi di verificazione"
-let trustee_public_keys = "chiavi pubbliche"
 let ballots = "schede elettorali"
 let election_server = "Server delle elezioni"
 let accepted_ballots = "Schede elettorali accettate"
@@ -94,6 +96,7 @@ let login = "Connettersi"
 let password_login = "Connessione tramite la password"
 let by_using_you_accept = "By using this site, you accept our "
 let privacy_policy = "personal data policy"
+let privacy_policy_short = "Privacy policy"
 let accept = "Accettare"
 let not_yet_open = "Spiacente, quest'elezione non è ancora aperta"
 let come_back_later = "Quest'elezione ancora non esiste. La preghiamo di consultare ulteriormente."
@@ -101,16 +104,25 @@ let cookies_are_blocked = "I cookies sono bloccati"
 let please_enable_them = "Il suo browser non accetta i cookies. Si prega di attivarli."
 let election_currently_closed = "Questa elezione è chiusa per ora."
 let election_closed_being_tallied = "L'elezione è chiusa ed il conteggio è in corso."
-let the = " L'impronta del "
-let encrypted_tally = "risultato cifrato"
-let hash_is = " è "
 let election_has_been_tallied = "Questa elezione è stata conteggiata."
 let election_archived = "Questa elezione è archiviata."
 let number_accepted_ballots = "Numero di schede accettate : "
 let you_can_also_download = "È possibile scaricare il "
 let result_with_crypto_proofs = "risultato con le prove crittografiche"
+let the_raw_results = "The raw results can be viewed in the "
+let json_result = "JSON result"
+let it_contains_all_clear = ". It contains all submitted ballots in clear, in random order. It is up to you to apply your favorite counting method (e.g. Condorcet, STV, majority judgement)."
 let blank_vote = "Scheda bianca"
 let no_other_blank = "Nessun'altra scelta è autorizzata quando la scheda è bianca"
+let it_will_open_in = "It will open in "
+let the_election_will_close_in = "The election will close in "
+let years = " year(s)"
+let months = " month(s)"
+let days = " day(s)"
+let hours = " hour(s)"
+let minutes = " minute(s)"
+let seconds = " second(s)"
+let result_currently_not_public : ('a, 'b, 'c, 'd, 'e, 'f) format6 = "The result of this election is currently not publicly available. It will be in %s."
 
 
 let mail_password_subject : ('a, 'b, 'c, 'd, 'e, 'f) format6 =
@@ -201,6 +213,4 @@ let error_InvalidCredential = "your credential is invalid"
 let error_RevoteNotAllowed = "you are not allowed to revote"
 let error_ReusedCredential = "your credential has already been used"
 let error_WrongCredential = "you are not allowed to vote with this credential"
-let error_UsedCredential = "the credential has already been used"
-let error_CredentialNotFound = "the credential has not been found"
 let error_UnauthorizedVoter = "you are not allowed to vote"
