@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -25,7 +25,7 @@ let advanced_mode = "Mod avansat"
 let see_accepted_ballots = "Consultă buletinele de vot acceptate"
 let belenios_booth = "Cabina de vot Belenios"
 let here = "aici"
-let question_header = "Întrebarea #%d din %d — selectați între %d și %d rspuns(uri)"
+let question_header = "Selectați între %d și %d rspuns(uri)"
 let at_least = "Trebuie să selectați cel puțin %d răspuns(uri)"
 let at_most = "Trebuie să selectați cel mult %d răspuns(uri)"
 let previous = "Precedent"
@@ -33,14 +33,17 @@ let next = "Următor"
 let nothing = "(nimic)"
 let enter_cred = "Vă rugăm să introduceți codul de votare:"
 let invalid_cred = "Cod de votare invalid !"
-let input_credential = "Introdu codul de votare"
-let answer_to_questions = "Răspunde la întrebări"
+let input_credential = "Introducere cod de votare"
+let answer_to_questions = "Răspuns la întrebări"
+let warning_0_255 = "Warning: the system will accept any integer between 0 and 255 but, according to the election rules, invalid ballots (score too high or candidates not properly ranked) will be rejected at the end of the election."
+let alert_0_255 = "Value must be an integer between 0 and 255."
+let at_least_one_invalid = "At least one of the answers is invalid!"
 let review_and_encrypt = "Rezumat și criptare"
 let authenticate = "Autentificare"
 let confirm = "Confirmare"
-let done_ = "Terminare"
-let booth_step1 = "Pas 1/6: Introduceți codul de votare"
-let booth_step2 = "Pas 2/6: Răspunde la întrebări"
+let done_ = "Terminat"
+let booth_step1 = "Pas 1/6: Introducere cod de votare"
+let booth_step2 = "Pas 2/6: Răspuns la întrebări"
 let booth_step3 = "Pas 3/6: Rezumat și criptare"
 let booth_step5 = "Pas 5/6: Confirmare"
 let booth_step6 = "Pas 6/6: "
@@ -55,7 +58,7 @@ let your_tracker_is = "Numărul vostru de identificare este "
 let we_invite_you_to_save_it = "Vă invităm să-l salvați pentru a verifica ulterior că votul vostru este luat în considerare."
 let continue = "Continuă"
 let election_uuid = "Codul UUID al alegerii: "
-let election_fingerprint = "Amprenta digitală al alegerii: "
+let election_fingerprint = "Amprenta digitală a alegerii: "
 let i_am = "Eu sunt "
 let and_ = " și "
 let i_cast_my_vote = "Am depus votul meu"
@@ -63,12 +66,12 @@ let please_login_to_confirm = "Vă rugăm să vă logați pentru a confirma votu
 let your_ballot_for = "Buletinul de vot pentru "
 let has_been_received = " a fost primit, dar nu a fost încă înregistrat. "
 let nobody_can_see = "Notă: buletinul de vot este criptat și nimeni nu-i poate vedea conținutul."
-let you_have_already_voted = "Note: you have already voted. Your vote will be replaced."
-let go_back_to_election = "Întoarcete la pagina de start a alegerii"
+let you_have_already_voted = "Notă: ați votat deja. Votul vostru va fi înlocuit."
+let go_back_to_election = "Întoarcere la pagina de start a alegerii"
 let has_been_accepted = " a fost acceptat."
-let you_can_check_its_presence = "Puteți verifica prezența în "
+let you_can_check_its_presence = "Puteți verifica prezența sa în "
 let ballot_box = "urna de vot"
-let anytime_during_the_election = " în orice moment al alegerii."
+let anytime_during_the_election = " în orice moment din perioada alegerii."
 let confirmation_email = " Un e-mail de confirmare v-a fost trimis."
 let thank_you_for_voting = "Vă mulțumim pentru participare!"
 let is_rejected_because = " este resprins, deoarece "
@@ -80,7 +83,6 @@ let get_the_source_code = "Obține codul sursă"
 let audit_data = "Date de audit: "
 let parameters = "parametrii"
 let public_credentials = "chei de verificare"
-let trustee_public_keys = "cheia publică"
 let ballots = "buletine de vot"
 let election_server = "Server al alegerii"
 let accepted_ballots = "Buletinele de vot acceptate"
@@ -92,25 +94,35 @@ let username = "Nume utilizator:"
 let password = "Parola:"
 let login = "Conectare"
 let password_login = "Conectare folosind parola"
-let by_using_you_accept = "By using this site, you accept our "
-let privacy_policy = "personal data policy"
+let by_using_you_accept = "Folosind acest sit, acceptați "
+let privacy_policy = "politica noastră privind datele personale"
+let privacy_policy_short = "Privacy policy"
 let accept = "Accept"
 let not_yet_open = "Din păcate, această alegere nu este încă deschisă"
 let come_back_later = "Acesta alegere nu există încă. Vă rugăm să reveniți mai târziu."
 let cookies_are_blocked = "Cookie-urile sunt blocate"
 let please_enable_them = "Browser-ul dumneavoastră pare să blocheze cookie-urile. Vă rugăm să le activați."
 let election_currently_closed = "Această alegere este în prezent închisă."
-let election_closed_being_tallied = "Această alegere este închisă și în curs de contorizare."
-let the = " Amprenta "
-let encrypted_tally = "rezultatului criptat"
-let hash_is = " este "
+let election_closed_being_tallied = "Alegerea este închisă și în curs de contorizare."
 let election_has_been_tallied = "Această alegere a fost contorizata."
 let election_archived = "Această alegere este arhivată."
 let number_accepted_ballots = "Numărul buletinelor de vot acceptate: "
 let you_can_also_download = "De asemenea, puteți descărca "
-let result_with_crypto_proofs = "rezultat cu dovada criptografică"
+let result_with_crypto_proofs = "rezultatul împreună cu dovada criptografică"
+let the_raw_results = "The raw results can be viewed in the "
+let json_result = "JSON result"
+let it_contains_all_clear = ". It contains all submitted ballots in clear, in random order. It is up to you to apply your favorite counting method (e.g. Condorcet, STV, majority judgement)."
 let blank_vote = "Vot alb"
 let no_other_blank = "Nu puteți selecta o altă opțiune la un vot alb"
+let it_will_open_in = "Se va deschide în "
+let the_election_will_close_in = "Alegerea se va închide în "
+let years = " an(i)"
+let months = " luna(i)"
+let days = " zi(le) "
+let hours = " ora(e)"
+let minutes = " minut(e)"
+let seconds = " secundă(e)"
+let result_currently_not_public : ('a, 'b, 'c, 'd, 'e, 'f) format6 = "Rezultatul acestei alegeri nu este disponibil deocamdată. Va fi disponibil în %s."
 
 
 let mail_password_subject : ('a, 'b, 'c, 'd, 'e, 'f) format6 =
@@ -179,25 +191,23 @@ a fost înregistrat. Numărul vostru de identificare este
   %s%s
 
 
-Puteți verifica prezența acestuia în urma de vot, accesibilă la
+Puteți verifica prezența acestuia în urna de vot, accesibilă la
   %s
 
-Rezultatele vor fi publicate pe pagina de alegere
+Rezultatele vor fi publicate pe pagina alegerii
   %s%s
 
 -- \nBelenios"
 
-let this_vote_replaces = "\n\nThis vote replaces any previous vote."
-let please_contact = "To get more information, please contact:"
+let this_vote_replaces = "\n\nAcest vot înlocuiește orice vot precedent."
+let please_contact = "Pentru a obține mai multe informații, va rugăm contactați:"
 
-let error_Serialization : ('a, 'b, 'c, 'd, 'e, 'f) format6 = "your ballot has a syntax error (%s)"
-let error_ProofCheck = "some proofs failed verification"
-let error_ElectionClosed = "the election is closed"
-let error_MissingCredential = "a credential is missing"
-let error_InvalidCredential = "your credential is invalid"
-let error_RevoteNotAllowed = "you are not allowed to revote"
-let error_ReusedCredential = "your credential has already been used"
-let error_WrongCredential = "you are not allowed to vote with this credential"
-let error_UsedCredential = "the credential has already been used"
-let error_CredentialNotFound = "the credential has not been found"
-let error_UnauthorizedVoter = "you are not allowed to vote"
+let error_Serialization : ('a, 'b, 'c, 'd, 'e, 'f) format6 = "buletinul vostru de vot are o eroare sintactică (%s)"
+let error_ProofCheck = "unele dovezi sunt invalide"
+let error_ElectionClosed = "alegerea este inchisă"
+let error_MissingCredential = "un cod de votare lipsește"
+let error_InvalidCredential = "codul vostru de votare este invalid"
+let error_RevoteNotAllowed = "nu sunteți autorizați să revotați"
+let error_ReusedCredential = "codul vostru de votare a vost deja utilizat"
+let error_WrongCredential = "nu sunteți autorizați să votați cu acest cod de vot"
+let error_UnauthorizedVoter = "nu sunteți autorizați să votați"
