@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -22,40 +22,68 @@
 open Serializable_t
 open Common
 open Web_serializable_t
+open Web_common
+
+val get_draft_election : uuid -> draft_election option Lwt.t
+val set_draft_election : uuid -> draft_election -> unit Lwt.t
 
-type election_state =
-  [ `Open
-  | `Closed
-  | `EncryptedTally of int * int * string
-  | `Tallied of plaintext
-  | `Archived
-  ]
 val get_election_state : uuid -> election_state Lwt.t
 val set_election_state : uuid -> election_state -> unit Lwt.t
 
-val get_election_date : uuid -> datetime Lwt.t
-val set_election_date : uuid -> datetime -> unit Lwt.t
+val get_election_dates : uuid -> election_dates Lwt.t
+val set_election_dates : uuid -> election_dates -> unit Lwt.t
 
-val get_partial_decryptions : uuid -> (int * string) list Lwt.t
-val set_partial_decryptions : uuid -> (int * string) list -> unit Lwt.t
+val get_partial_decryptions : uuid -> partial_decryptions Lwt.t
+val set_partial_decryptions : uuid -> partial_decryptions -> unit Lwt.t
 
-val get_auth_config : uuid option -> (string * (string * string list)) list Lwt.t
-val set_auth_config : uuid option -> (string * (string * string list)) list -> unit Lwt.t
+val get_decryption_tokens : uuid -> decryption_tokens option Lwt.t
+val set_decryption_tokens : uuid -> decryption_tokens -> unit Lwt.t
 
 val get_raw_election : uuid -> string option Lwt.t
 val get_election_metadata : uuid -> metadata Lwt.t
-val get_election_result : uuid -> Yojson.Safe.json result option Lwt.t
+val get_election_result : uuid -> Yojson.Safe.t election_result option Lwt.t
 
-val get_elections_by_owner : user -> uuid list Lwt.t
+val get_election_result_hidden : uuid -> datetime option Lwt.t
+val set_election_result_hidden : uuid -> datetime option -> unit Lwt.t
+
+type election_kind =
+  [ `Draft
+  | `Validated
+  | `Tallied
+  | `Archived
+  ]
+val get_elections_by_owner : user -> (election_kind * uuid * datetime * string) list Lwt.t
 
 val get_voters : uuid -> string list option Lwt.t
 val get_passwords : uuid -> (string * string) SMap.t option Lwt.t
-val get_public_keys : uuid -> string list option Lwt.t
 val get_private_key : uuid -> number option Lwt.t
 val get_private_keys : uuid -> string list option Lwt.t
-val get_threshold : uuid -> string option Lwt.t
+val get_trustees : uuid -> string Lwt.t
+val convert_trustees : unit -> unit Lwt.t
 
 val get_ballot_hashes : uuid -> string list Lwt.t
 val get_ballot_by_hash : uuid -> string -> string option Lwt.t
 
+val compute_encrypted_tally : uuid -> string option Lwt.t
+
+val get_shuffles : uuid -> string list option Lwt.t
+val get_shuffle_hashes : uuid -> shuffle_hash list option Lwt.t
+val add_shuffle_hash : uuid -> shuffle_hash -> unit Lwt.t
+val compute_encrypted_tally_after_shuffling : uuid -> string option Lwt.t
+
+val get_shuffle_token : uuid -> shuffle_token option Lwt.t
+val gen_shuffle_token : uuid -> string -> shuffler -> shuffle_token Lwt.t
+val clear_shuffle_token : uuid -> unit Lwt.t
+
+val get_nh_ciphertexts : uuid -> string Lwt.t
+
+val append_to_shuffles : uuid -> string -> string option Lwt.t
+
 val has_voted : uuid -> user -> bool Lwt.t
+
+val init_credential_mapping : uuid -> string list -> unit Lwt.t
+
+val cast_ballot : uuid -> rawballot:string -> user:string -> datetime -> (string * bool, cast_error) result Lwt.t
+
+val get_audit_cache : uuid -> audit_cache Lwt.t
+val remove_audit_cache : uuid -> unit Lwt.t
