@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -20,62 +20,18 @@
 (**************************************************************************)
 
 open Lwt
-open Web_serializable_t
-
-type user = {
-  uuid: uuid option;
-  service : string;
-  name : string;
-}
 
 let scope = Eliom_common.default_session_scope
 
 let show_cookie_disclaimer = Eliom_reference.eref ~scope true
 
-let user = Eliom_reference.eref ~scope None
-
-let get_site_user () =
-  match%lwt Eliom_reference.get user with
-  | None -> return None
-  | Some u ->
-     match u.uuid with
-     | None ->
-        return @@ Some {
-          user_domain = u.service;
-          user_name = u.name;
-        }
-     | Some _ -> return None
+let site_user = Eliom_reference.eref ~scope None
+let election_user = Eliom_reference.eref ~scope None
 
 let get_election_user uuid =
-  match%lwt Eliom_reference.get user with
-  | None -> return None
-  | Some u ->
-     match u.uuid with
-     | None -> return None
-     | Some uuid' ->
-        if uuid = uuid' then
-          return @@ Some {
-            user_domain = u.service;
-            user_name = u.name
-          }
-        else
-          return None
-
-
-let cont = Eliom_reference.eref ~scope []
-
-let cont_push f =
-  let open Eliom_reference in
-  let%lwt fs = get cont in
-  set cont (f :: fs)
-
-let cont_pop () =
-  let open Eliom_reference in
-  let%lwt fs = get cont in
-  match fs with
-  | f :: fs -> set cont fs >> return (Some f)
-  | [] -> return None
-
+  match%lwt Eliom_reference.get election_user with
+  | Some (u, x) when u = uuid -> return_some x
+  | _ -> return_none
 
 let ballot = Eliom_reference.eref ~scope None
 let cast_confirmed = Eliom_reference.eref ~scope None
@@ -87,9 +43,12 @@ let get_default_language () =
   | [] -> "en"
   | (lang, _) :: _ ->
      let n =
-       try String.index lang '-'
-       with Not_found -> String.length lang
+       match String.index_opt lang '-' with
+       | Some x -> x
+       | None -> String.length lang
      in
      String.sub lang 0 n
 
 let language = Eliom_reference.eref_from_fun ~scope get_default_language
+
+let signup_env = Eliom_reference.eref ~scope None
