@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2018 Inria                                           *)
+(*  Copyright © 2012-2020 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -19,26 +19,17 @@
 (*  <http://www.gnu.org/licenses/>.                                       *)
 (**************************************************************************)
 
-open Serializable_builtin_t
-open Web_signatures
-
-type user = {
-  uuid: uuid option;
-  service : string;
-  name : string;
-}
+open Web_serializable_t
 
 val show_cookie_disclaimer : bool Eliom_reference.eref
 
-val user : user option Eliom_reference.eref
-val get_site_user : unit -> Web_serializable_t.user option Lwt.t
-val get_election_user : uuid -> Web_serializable_t.user option Lwt.t
-
-val cont : (unit -> content) list Eliom_reference.eref
-val cont_push : (unit -> content) -> unit Lwt.t
-val cont_pop : unit -> (unit -> content) option Lwt.t
+val site_user : user option Eliom_reference.eref
+val election_user : (uuid * user) option Eliom_reference.eref
+val get_election_user : uuid -> user option Lwt.t
 
 val ballot : string option Eliom_reference.eref
-val cast_confirmed : [ `Error of Web_common.error | `Valid of string ] option Eliom_reference.eref
+val cast_confirmed : (string, Web_common.error) result option Eliom_reference.eref
 
 val language : string Eliom_reference.eref
+
+val signup_env : (string * string * string * Web_signup.link_kind) option Eliom_reference.eref
